==> bootstrap_italia-2.0.2.tar.gz: bootstrap_italia/var/starter_kits/italiagov/src/js/index.js <==
/**
 * Main entry
 * This file will be updated periodically by the maintainers,
 * please do not make any changes.
 *
 * For your custom scripts use the 'custom' folder,
 * import your scripts using './custom/custom.js'.
 */

// Import Bootstrap 5.
import { Alert, Button, Carousel, Collapse, Dropdown, Modal, Offcanvas, Popover, ScrollSpy, Tab, Toast, Tooltip } from 'bootstrap'

// Import Bootstrap Italia.
import { loadPlugin } from 'bootstrap-italia/src/js/load-plugin'
import * as fontsLoader from 'bootstrap-italia/src/js/plugins/fonts-loader'
import * as icons from 'bootstrap-italia/src/js/icons'
import * as headerSticky from 'bootstrap-italia/src/js/plugins/header-sticky'

import BOOTSTRAP_ITALIA_VERSION from 'bootstrap-italia/src/js/version'

loadPlugin(icons)
loadPlugin(fontsLoader)
loadPlugin(headerSticky)

import {
  Dimmer,
  Notification,
  Cookiebar,
  NavBarCollapsible,
  Accordion,
  NavScroll,
  TrackFocus,
  CarouselBI,
  FormValidate,
  ValidatorSelectAutocomplete,
  Input,
  SelectAutocomplete,
  InputSearchAutocomplete,
  InputPassword,
  InputNumber,
  ProgressDonut,
  UploadDragDrop,
  BackToTop,
  Sticky,
  HistoryBack,
  Forward,
  Masonry,
  List,
  Transfer,
} from 'bootstrap-italia/src/js/bootstrap-italia.esm'

window.BOOTSTRAP_ITALIA_VERSION = BOOTSTRAP_ITALIA_VERSION

window.bootstrap = {
  Alert,
  Button,
  Carousel,
  Collapse,
  Dropdown,
  Modal,
  Offcanvas,
  Popover,
  ScrollSpy,
  Tab,
  Toast,
  Tooltip,
  Accordion,
  BackToTop,
  CarouselBI,
  Cookiebar,
  Dimmer,
  FormValidate,
  Forward,
  HistoryBack,
  Input,
  InputNumber,
  InputPassword,
  InputSearchAutocomplete,
  List,
  Masonry,
  NavBarCollapsible,
  NavScroll,
  Notification,
  ProgressDonut,
  SelectAutocomplete,
  Sticky,
  TrackFocus,
  Transfer,
  UploadDragDrop,
  ValidatorSelectAutocomplete,
}

// Component library initialization.
import './component-library-initialization'

// Import custom JS.
import './custom/custom'

==> bootstrap_italia-2.7.0.tar.gz: bootstrap_italia/var/starter_kits/italiagov/src/js/index.js <==
/**
 * Main entry
 * This file will be updated periodically by the maintainers,
 * if you modify it check the version changes before opening an issue.
 *
 * For your custom scripts use the 'custom' folder,
 * import your scripts using './custom/custom.js'.
 */

// Import Bootstrap-italia components.
import { loadPlugin } from 'bootstrap-italia/src/js/load-plugin'
import init from 'bootstrap-italia/src/js/plugins/init'
import * as icons from 'bootstrap-italia/src/js/icons'

/**
 * Import all components, to choose components use
 * import {ComponentA, ComponentB, ...} from 'bootstrap-italia'.
 *
 * Docs: https://italia.github.io/bootstrap-italia/docs/come-iniziare/introduzione/#javascript
 * Examples: https://github.com/astagi/demo-bsitalia-2
 */
import {
  Alert,
  Button,
  Carousel,
  Collapse,
  Dropdown,
  Modal,
  Offcanvas,
  Popover,
  ScrollSpy,
  Tab,
  Toast,
  Tooltip,
  Accordion,
  BackToTop,
  CarouselBI,
  Cookiebar,
  Dimmer,
  FormValidate,
  Forward,
  HistoryBack,
  Input,
  InputNumber,
  InputPassword,
  InputSearchAutocomplete,
  List,
  Masonry,
  NavBarCollapsible,
  NavScroll,
  Notification,
//  ProgressDonut,
  SelectAutocomplete,
  Sticky,
  HeaderSticky,
  Transfer,
  UploadDragDrop,
  ValidatorSelectAutocomplete,
  loadFonts,
} from 'bootstrap-italia'

loadPlugin(icons)
init()

const bootstrap = {
  Alert,
  Button,
  Carousel,
  Collapse,
  Dropdown,
  Modal,
  Offcanvas,
  Popover,
  ScrollSpy,
  Tab,
  Toast,
  Tooltip,
  Accordion,
  BackToTop,
  CarouselBI,
  Cookiebar,
  Dimmer,
  FormValidate,
  Forward,
  HistoryBack,
  Input,
  InputNumber,
  InputPassword,
  InputSearchAutocomplete,
  List,
  Masonry,
  NavBarCollapsible,
  NavScroll,
  Notification,
  SelectAutocomplete,
  Sticky,
  HeaderSticky,
  Transfer,
  UploadDragDrop,
  ValidatorSelectAutocomplete,
  loadFonts,
}

// Component library initialization.
import './component-library-initialization'

// Import custom JS.
import './custom/custom'

/**
 * Export all bootstrap-italia components as `bootstrap`,
 * use your custom.js to customize object.
 *
 * @type {any}
 */
window.bootstrap = bootstrap
